<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>PanZoom</name>
    <message>
        <location filename="../PanZoomInit.js" line="+2"/>
        <source>&amp;Pan Zoom</source>
        <translation>&amp;Posun pohledu</translation>
    </message>
</context>
</TS>
